@@ -1,6 +1,6 @@
 from __future__ import annotations
 import os
-
+from modelz.utils import strtobool
 
 PREFIX: str = "MODELZ_"
 
@@ -12,7 +12,9 @@ class EnvConfig:
         self.update_from_env()
 
     def update_from_env(self):
-        for key in ("api_key", "host"):
+        for key in ("api_key", "host", "ssl_verify"):
             val = os.environ.get(f"{PREFIX}{key.upper()}")
+            if key == 'ssl_verify' and val is not None:
+                val = strtobool(val)
             if val is not None:
                 setattr(self, key, val)
